Learn R Programming

bayesPop (version 0.2-2)

MigByAgeMale2008: Datasets on Migration

Description

Datasets giving prediction of male and female age-specific net migration.

Usage

data(MigByAgeMale2008)
data(MigByAgeMale2010)

data(MigByAgeFemale2008) data(MigByAgeFemale2010)

Arguments

source

Data provided by the United Nations Population Division

Details

There is one record for each country and each age. Thus, for each country there are 21 records. The country records must be groupped together with age records following the order above.

Examples

Run this code
data(MigByAgeMale2010)
str(MigByAgeMale2010)

Run the code above in your browser using DataLab