## Not run:
# sim.dir <- tempfile()
# # Generates population projection for one country
# country <- 'Netherlands'
# pred <- pop.predict(countries=country, output.dir=sim.dir)
# summary(pred, country)
# pop.trajectories.plot(pred, country)
# pop.pyramid(pred, country)
# pop.pyramid(pred, country, year=2100, age=1:26)
# unlink(sim.dir, recursive=TRUE)
# ## End(Not run)
# Here are commands needed to run probabilistic projections
# from scratch, i.e. including TFR and life expectancy.
# Note that running the first four commands
# (i.e. predicting TFR and life expectancy) can take
# LONG time (up to several days; see below for possible speed-up).
# For a toy simulation, set the number of iterations (iter)
# to a small number.
## Not run:
# sim.dir.tfr <- 'directory/for/TFR'
# sim.dir.e0 <- 'directory/for/e0'
# sim.dir.pop <- 'directory/for/pop'
#
# # Estimate TFR parameters (speed-up by including parallel=TRUE)
# run.tfr.mcmc(iter='auto', output.dir=sim.dir.tfr, seed=1)
#
# # Predict TFR (if iter above < 4000, reduce burnin and nr.traj accordingly)
# tfr.predict(sim.dir=sim.dir.tfr, nr.traj=2000, burnin=2000)
#
# # Estimate e0 parameters (females) (speed-up by including parallel=TRUE)
# # Can be run independently of the two commands above
# run.e0.mcmc(sex='F', iter='auto', output.dir=sim.dir.e0, seed=1)
#
# # Predict female and male e0
# # (if iter above < 22000, reduce burnin and nr.traj accordingly)
# e0.predict(sim.dir=sim.dir.e0, nr.traj=2000, burnin=20000)
#
# # Population prediction
# pred <- pop.predict(output.dir=sim.dir.pop, verbose=TRUE,
# inputs = list(tfr.sim.dir=sim.dir.tfr,
# e0F.sim.dir=sim.dir.e0, e0M.sim.dir='joint_'))
# pop.trajectories.plot(pred, 'Madagascar', nr.traj=50, sum.over.ages=TRUE)
# pop.trajectories.table(pred, 'Madagascar')
# ## End(Not run)
Run the code above in your browser using DataLab