Learn R Programming

bayesPop (version 3.2-3)

summary.bayesPop.prediction: Summary of Probabilistic Population Projection

Description

Summary of an object bayesPop.prediction created using the pop.predict function. The summary contains the mean, standard deviation and several commonly used quantiles of the simulated trajectories.

Usage

## S3 method for class 'bayesPop.prediction':
summary(object, country = NULL, 
    sex = c("both", "male", "female"), compact = TRUE, ...)

Arguments

object
Object of class bayesPop.prediction.
country
Country name or code. If it is NULL, only meta information included.
sex
One of both (default), male, or female. If it is not both, the summary is given for sex-specific trajectories.
compact
Logical switching between a smaller and larger number of displayed quantiles.
...
A list of further arguments.

See Also

bayesPop.prediction

Examples

Run this code
sim.dir <- file.path(find.package("bayesPop"), "ex-data", "Pop")
pred <- get.pop.prediction(sim.dir)
summary(pred, "Netherlands")

Run the code above in your browser using DataLab