Learn R Programming

bayesPop (version 6.0-1)

vwBaseYear: Datasets on Migration Base Year and Type, and Mortality and Fertility Age Patterns

Description

Datasets giving information on the baseyear and type of migration for each country. The 2012 and 2015 datasets also give information on country's specifics regarding mortality and fertility age patterns.

Usage

data(vwBaseYear2015) data(vwBaseYear2012) data(vwBaseYear2010)

Arguments

Format

A data frame containing the following variables:
country_code
Numerical Location Code (3-digit codes following ISO 3166-1 numeric standard) - see http://en.wikipedia.org/wiki/ISO_3166-1_numeric.
country
Country name. Not used by the package.
isSmall
UN internal code. Not used by the package.
ProjFirstYear
The base year of migration.
MigCode
Type of migration. Zero means migration is evenly distributed over each time interval. Code 9 means migration is captured at the end of each interval.
WPPAIDS
Dummy indicating if the country has generilized HIV/AIDS epidemics.
AgeMortalityType
Type of mortality age pattern. Only relevant for countries with the entry “Model life tables”. In such a case, the $b_x$ Lee-Carter parameter is not estimated from historical data. Instead is taken from the dataset MLTbx using a pattern given in the AgeMortalityPattern column.
AgeMortalityPattern
If AgeMortalityType is equal to “Model life tables”, this value determines which $b_x$ is selected from the MLTbx dataset. It must sorrespond to one of the rownames of MLTbx, e.g. “CD East”, “CD West”, “UN Latin American”.
LatestAgeMortalityPattern
Dummy indicating if the $a_x$ Lee-Carter parameter should be computed using observed data from the latest time period only.
SmoothLatestAgeMortalityPattern
If LatestAgeMortalityPattern is 1, this column indicates if the $a_x$ should be smoothed.
PasfrNorm
Type of norm for computing age-specific fertility patern to which the country belongs to. Currently only “GlobalNorm” is used.
PasfrGlobalNorm, PasfrFarEastAsianNorm, PasfrSouthAsianNorm
Dummies indicating which country to include to compute the specific norms.

Data provided by the United Nations Population Division.

Details

There is one record for each country. See Sevcikova et al (2015) on how information from the various columns is used for projections.

References

H. Sevcikova, N. Li, V. Kantorova, P. Gerland and A. E. Raftery (2015). Age-Specific Mortality and Fertility Rates for Probabilistic Population Projections. arXiv:1503.05215. http://arxiv.org/abs/1503.05215

Examples

Run this code
data(vwBaseYear2015)
str(vwBaseYear2015)

Run the code above in your browser using DataLab