PopByAgeMale2008: Datasets of Initial Population
Description
Male and female datasets of initial population (i.e. at present time). Each dataset is connected to a WPP year which is part of the dataset name.Usage
data(PopByAgeMale2008)
data(PopByAgeMale2010)data(PopByAgeFemale2008)
data(PopByAgeFemale2010)
source
Data provided by the United Nations Population DivisionDetails
There is one record for each country and each age. Thus, for each country there are 21 records. The country records must be groupped together with age records following the order above.