Learn R Programming

bayesPop (version 0.2-2)

bayesPop-package: Probabilistic Population Projection

Description

The package allows to generate population projections for all countries of the world using several probabilistic components, such as total fertility rate (TFR) and life expectancy.

Arguments

Details

ll{ Package: bayesPop Type: Package Version: 0.2-2 Date: 2012-04-13 License: GPL (>=2) URL: http://bayespop.csss.washington.edu } The main function is called pop.predict. It uses trajectories of TFR from the bayesTFR package and life expectancy from the bayesLife package and for each trajectory it computes a population projection using the Cohort component method. It results in probabilistic age and sex specific projections. Various plotting functions are available for results visualization (pop.trajectories.plot, pop.pyramid, pop.trajectories.pyramid), as well as a summary function (summary.bayesPop.prediction).

See Also

bayesTFR, bayesLife

Examples

Run this code
sim.dir <- tempfile()
# Generates population projection for one country
country <- 'Netherlands'
pred <- pop.predict(countries=country, nr.traj=10, output.dir=sim.dir)
summary(pred, country)
pop.trajectories.plot(pred, country)
pop.pyramid(pred, country)
pop.pyramid(pred, country, year=2100, age=1:26)
unlink(sim.dir, recursive=TRUE)

Run the code above in your browser using DataLab