Function get.pop.prediction retrieves results of a prediction from disk and creates an object of class bayesPop.prediction. Function has.pop.prediction checks an existence of such results.
Usage
get.pop.prediction(sim.dir, aggregation = NULL)
has.pop.prediction(sim.dir)
Arguments
sim.dir
Directory where the prediction is stored. It should correspond to the value of the output.dir argument used in the pop.predict function.
aggregation
If given, the prediction object is considered to be an aggregation and both arguments are passed to get.pop.aggregation.
Value
Function has.pop.prediction returns a logical indicating if a prediction exists.
Function get.pop.prediction returns an
object of class bayesPop.prediction.
Details
The pop.predict function stores resulting trajectories into a directory called output.dir/prediction. Here the argument sim.dir should correspond to output.dir (i.e. without the prediction part).