pop.pyramid(pop.pred, country, year = NULL, pi = c(80, 95),
proportion = FALSE, main = NULL, age = 1:21)
pop.pyramid.all(pop.pred, year = NULL,
output.dir = file.path(getwd(), 'pop.pyramid'),
output.type = "png", verbose = FALSE, ...)
pop.trajectories.pyramid(pop.pred, country, year = NULL, pi = c(80, 95),
nr.traj = NULL, proportion = FALSE, main = NULL, age = 1:21)
pop.trajectories.pyramid.all(pop.pred, year = NULL,
output.dir = file.path(getwd(), 'pop.traj.pyramid'),
output.type = "png", verbose = FALSE, ...)bayesPop.prediction.pop.pyramid.all and pop.trajectories.pyramid.all, the year argument can be a vector of years.TRUE the pyramid contains the distribution of rates of age-specific counts and population totals.NULL, all trajectories are plotted, otherwise they are thinned evenly.pop.pyramid function generates a population pyramid that includes given confidence intervals. pop.pyramid.all creates such pyramids for all countries for which a projection is available and for all years given by the year argument.Functions pop.trajectories.pyramid and pop.trajectories.pyramid.all work in a similar way. The only difference is that the pyramid is created using the population trajectories.
pop.trajectories.plot, bayesPop.prediction, summary.bayesPop.predictionsim.dir <- file.path(.find.package("bayesPop"), "ex-data", "Pop")
pred <- get.pop.prediction(sim.dir)
pop.pyramid(pred, "Netherlands", 2045)
pop.trajectories.pyramid(pred, "Netherlands", 2045, age=1:25)Run the code above in your browser using DataLab