data(vwBaseYear2015) data(vwBaseYear2012) data(vwBaseYear2010)country_codecountryisSmallProjFirstYearMigCodeWPPAIDSAgeMortalityTypeMLTbx using a pattern given in the AgeMortalityPattern column.AgeMortalityPatternAgeMortalityType is equal to Model life tables, this value determines which $b_x$ is selected from the MLTbx dataset. It must sorrespond to one of the rownames of MLTbx, e.g. CD East, CD West, UN Latin American.LatestAgeMortalityPatternSmoothLatestAgeMortalityPatternLatestAgeMortalityPattern is 1, this column indicates if the $a_x$ should be smoothed.PasfrNormPasfrGlobalNorm, PasfrFarEastAsianNorm, PasfrSouthAsianNormdata(vwBaseYear2015)
str(vwBaseYear2015)
Run the code above in your browser using DataLab