Learn R Programming

bayesPop (version 6.0-0)

vwBaseYear: Datasets on Migration Base Year and Type, and Mortality and Fertility Age Patterns

Description

Datasets giving information on the baseyear and type of migration for each country. The 2012 and 2015 datasets also give information on country's specifics regarding mortality and fertility age patterns.

Usage

data(vwBaseYear2015)
    data(vwBaseYear2012) 
    data(vwBaseYear2010)

Arguments

source

Data provided by the United Nations Population Division.

Details

There is one record for each country. See Sevcikova et al (2015) on how information from the various columns is used for projections.

References

H. Sevcikova, N. Li, V. Kantorova, P. Gerland and A. E. Raftery (2015). Age-Specific Mortality and Fertility Rates for Probabilistic Population Projections. arXiv:1503.05215. http://arxiv.org/abs/1503.05215

Examples

Run this code
data(vwBaseYear2015)
str(vwBaseYear2015)

Run the code above in your browser using DataLab