Learn R Programming

bayesPop (version 5.4-0)

vwBaseYear: Datasets on Migration Base Year and Type, and Mortality and Fertility Age Patterns

Description

Datasets giving information on the baseyear and type of migration for each country. The 2012 dataset also gives information on country's specifics regarding mortality and fertility age patterns.

Usage

data(vwBaseYear2008)
    data(vwBaseYear2010) 
    data(vwBaseYear2012)

Arguments

source

Data provided by the United Nations Population Division.

Details

There is one record for each country.

Examples

Run this code
data(vwBaseYear2012)
str(vwBaseYear2012)

Run the code above in your browser using DataLab